# colorcodetools

![PyPI - Downloads](https://img.shields.io/pypi/dw/colorcodetools?style=flat-square) ![License](https://img.shields.io/github/license/TheKeineAhnung/colorcodetools?style=flat-square) 
![PyPI](https://img.shields.io/pypi/v/colorcodetools?style=flat-square)

## What is colorcodetools?
Colorcodetools is a python library for some simple operations with color codes.

## Install the project
1. Open your Terminal
2. Type: `pip install colorcodetools`
3. Read the docs for information how to use

## Where can I find the documentation
You can find the documentation in the [docs](https://github.com/TheKeineAhnung/colorcodetools/tree/main/docs) folder on GitHub.
